/*
 *	Allows aliens to see how much resources their teammates have.
 *
 *
 *	Commands:	say /res -	to display teammates resources
 *			+showres -	bind to a key to allow display of resources when a button is held down
 *
 *	Cvars:		amx_teamres_showusage - Set to 0 to disable the display of usage of this plugin to aliens
 *						at the start of the game. (default 1)
 *    
 *	Requires:	AMXModx 0.20 TP5, ns module, engine module
 *
 *	Author:		Cheesy Peteza  
 *	Date:		23-September-2004
 *	irc:		#yo-clan (QuakeNet)
 *
 */

#include <amxmodx>
#include <ns>
#include <engine>

#define HUD_CHANNEL	1	// 1-4 imessage(1) ScrollMsg(2) AlienUpgInfo(3)
#define MAX_ROW_SIZE	48
#define MARINE		1
#define ALIEN		2

enum playerData {
	PD_RES,
	PD_LINE[MAX_ROW_SIZE]
}

new g_maxPlayers
new bool:g_taskSet

public plugin_init() {
	register_plugin("Team Resources Display", "2.3", "Cheesy Peteza")
	register_cvar("teamres_version", "2.3", FCVAR_SERVER)

	g_maxPlayers = get_maxplayers()

	if ( !ns_is_combat() ) {
		register_clcmd("say /res", "sayShowRes")
		register_clcmd("say_team /res", "sayShowRes")
		register_clcmd("+showres", "cmdShowRes")
		register_clcmd("-showres", "cmdHideRes")

		register_cvar("amx_teamres_showusage", "1")
		register_event("Countdown", "gameStarting", "a")
	}
}

public plugin_modules() {
	require_module("engine")
	require_module("ns")
}

public sayShowRes(id) {
	showRes(id)
	return PLUGIN_CONTINUE
}

showRes(id) {
	if ( entity_get_int(id, EV_INT_team) != ALIEN ) return

	new infoTable[256], pdata[32][playerData], pnum
	format(infoTable, 255, "RES^tCLASS^t^tNAME^n")

	for (new i = 1; i <= g_maxPlayers; ++i) {
		if ( !is_user_connected(i) ) continue
		if ( entity_get_int(i, EV_INT_team) != ALIEN ) continue

		new class[8], line[MAX_ROW_SIZE], name[32], ires, res[4]
		switch ( ns_get_class(i) ) {
			case CLASS_SKULK:	class = "SKULK "
			case CLASS_GORGE:	class = "GORGE"
			case CLASS_LERK:	class = "LERK^t "
			case CLASS_FADE:	class = "FADE^t "
			case CLASS_ONOS:	class = "ONOS^t "
			case CLASS_GESTATE:	class = "GEST^t "
			case CLASS_DEAD:	class = "DEAD^t "
		}
		get_user_name(i, name, 31)
		if ( equal(name, "[No C-D]", 8) ) {
			replace(name, 31, "[No C-D]", "")
		}
		
		ires = floatround(ns_get_res(i))
		if (ires < 10)		format(res, 3, "%i^t^t", ires)
		else if (ires < 100)	format(res, 3, "%i^t", ires)
		else 			format(res, 3, "%i", ires)

		format(line, MAX_ROW_SIZE-1, "%s^t%s^t^t%s^n", res, class, name)

		pdata[pnum][PD_RES] = ires
		copy(pdata[pnum++][PD_LINE], MAX_ROW_SIZE, line)

	}
	while (pnum < 32)
		pdata[pnum++][PD_RES] = -1

	for (new i; i < 32; ++i) {
		new maxresid = -1, maxres = -1
		for (new j; j < 32; ++j) {
			if (0 <= pdata[j][PD_RES] >= maxres) {
				maxresid = j
				maxres = pdata[j][PD_RES]
			}
		}
		if (maxresid == -1) break
		add(infoTable, 255, pdata[maxresid][PD_LINE], 255-strlen(pdata[maxresid][PD_LINE]))
		pdata[maxresid][PD_RES] = -1

	}

	set_hudmessage(0,255,0, 0.028, 0.15, 0, 0.5, 15.0, 0.5, 0.5, HUD_CHANNEL) 
	show_hudmessage(id, infoTable)
}

public cmdShowRes(id) {
	showRes(id)
	return PLUGIN_HANDLED
}

public cmdHideRes(id) {
	set_hudmessage(0,255,0, 0.028, 0.15, 0, 0.0, 0.1, 0.0, 0.0, HUD_CHANNEL) 
	show_hudmessage(id, " ")
	return PLUGIN_HANDLED
}

public gameStarting() {
	if (g_taskSet) return PLUGIN_HANDLED
	g_taskSet = true
	set_task(10.0, "showUsage")

	return PLUGIN_HANDLED
}

public showUsage() {
	g_taskSet = false
	if ( !get_cvar_num("amx_teamres_showusage") )
		return PLUGIN_HANDLED

	for (new id = 1; id <= g_maxPlayers; ++id) {
		if (!is_valid_ent(id)) continue
		if ( entity_get_int(id, EV_INT_team) != ALIEN ) continue
		client_print(id, print_chat, "[TeamRes] To see how many resources your teammates have, say /res or bind a key to +showres")
	}

	return PLUGIN_HANDLED
}

